@@ -2,7 +2,6 @@ from IPython.display import display_html
 from numpy import sort, nan, inf, float32, where, isin, argsort, array, select, append, quantile, linspace, argmin
 from pandas import DataFrame, Series, isna, qcut, notna, unique
 from sklearn.base import BaseEstimator, TransformerMixin
-from tqdm.notebook import tqdm
 from warnings import warn
 
 
@@ -189,7 +188,7 @@ class Discretizer(BaseEstimator, TransformerMixin):
         Exemple: for an `age` feature, `values_orders` could be `{'age': ['0-18', '18-30', '30-50', '50+']}`.
     """
     
-    def __init__(self, quanti_features: list, quali_features: list, q: int=None, min_freq: float=None, values_orders: dict=None, copy: bool=False, verbose: bool=False):
+    def __init__(self, quanti_features: list=[], quali_features: list=[], q: int=None, min_freq: float=None, values_orders: dict={}, copy: bool=False, verbose: bool=False):
     
         
         self.features = quanti_features[:] + quali_features[:]
@@ -248,8 +247,10 @@ class Discretizer(BaseEstimator, TransformerMixin):
             has_rare = list(frequencies[frequencies <= q_min_freq].index)
             if any(has_rare):
                 if self.verbose: print("\n---\n[Discretizer] Fitting Quantitative Features (that have rare values)")
+                print(has_rare)
 
                 rare_values_orders = {feature: order for feature, order in self.values_orders.items() if feature in has_rare}
+                print(rare_values_orders)
                 discretizer = ClosestDiscretizer(rare_values_orders, min_freq=q_min_freq, verbose=self.verbose)
                 discretizer.fit(Xc, y)
 
@@ -441,7 +442,7 @@ class QuantileDiscretizer(BaseEstimator, TransformerMixin):
 class ClosestDiscretizer(BaseEstimator, TransformerMixin):
     
     def __init__(self, values_orders: dict, min_freq: float, *, default: str='worst', copy: bool=False, verbose: bool=False):
-        """ Discretizes ordered qualitative features into groups of more frequent than min_freq"""
+        """ Discretizes ordered qualitative features into groups more frequent than min_freq"""
         
         self.features = list(values_orders.keys())
         self.min_freq = min_freq
@@ -454,8 +455,16 @@ class ClosestDiscretizer(BaseEstimator, TransformerMixin):
     def fit(self, X, y):
         
         # grouping rare modalities for each feature
-        common_modalities = X[self.features].apply(lambda u: find_common_modalities(u, y, self.min_freq, self.values_orders.get(u.name)), axis=0).to_dict()
+        common_modalities = X[self.features].apply(
+            lambda u: find_common_modalities(u, y, self.min_freq, self.values_orders.get(u.name)), 
+            axis=0
+        )
+        common_modalities.index = self.features  # making sure the indices are the features' names
+
+        # updating the order per feature
         self.values_orders = {f: common_modalities.get(f).get('order') for f in self.features}
+
+        # defining the default value based on the strategy
         self.default_values = {f: common_modalities.get(f).get(self.default) for f in self.features}
 
         return self
